#!/usr/bin/env python
# -*- coding: UTF-8 -*-
###########################################################################
#
# EOLE - 2012
# Copyright Pole de Competence Eole (Ministere Education - Academie Dijon)
# Licence CeCill  http://www.cecill.info/licences/Licence_CeCILL_V2-fr.html
# eole@ac-dijon.fr
#
###########################################################################
"""
script pour ajouter un personnel administrafif sur Scribe
"""

import sys
import getopt
from scribe.administratifs import Administratif
from scribe.errors import MissingUserCreateKey, LdapExistingUser
from scribe.eoletools import is_empty

def main():
    """
    boucle principale
    """
    try:
        options, args = getopt.getopt(sys.argv[1:],
            'u:m:p:f:d:M:w:x:q:G:P:sh',
            ['user=',
             'mdp=',
             'prenom=',
             'fnom=',
             'sexe=',
             'date_naiss=',
             'mail=',
             'quota=',
             'groupes=',
             'profil=',
             'shell',
             'help'])

    except getopt.GetoptError:
        er_type, er_value, er_traceback = sys.exc_info()
        er_msg = str(er_value)
        sys.exit("l'option -%s est inconnue ou nécessite un argument" % er_msg[er_msg.index('-')+1])

    prof = {}
    for (opt, val) in options:
        # login de l'enseignant
        if (opt == '-u') or (opt == '--user'):
            prof['login'] = val
        # mot de passe
        elif (opt == '-m') or (opt == '--mdp'):
            prof['password'] = val
        # prénom
        elif (opt == '-p') or (opt == '--prenom'):
            prof['prenom'] = val
        # nom (de famille)
        elif (opt == '-f') or (opt == '--fnom'):
            prof['nom'] = val
        # sexe 1/2/3
        elif (opt == '-x') or (opt == '--sexe'):
            prof['civilite'] = val
        # date de naissance
        elif (opt == '-d') or (opt == '--date_naiss'):
            prof['date'] = val
        # mail
        elif (opt == '-M') or (opt == '--mail'):
            prof['mail'] = val
        # groupes
        elif (opt == '-G') or (opt == '--groupes'):
            prof['groupe'] = val.split(',')
        # quota
        elif (opt == '-q') or (opt == '--quota'):
            prof['quota'] = val
        # profil
        elif (opt == '-P') or (opt == '--profil'):
            prof['profil'] = val
        # shell
        elif (opt == '-s') or (opt == '--shell'):
            prof['shell'] = True

        # et... l'aide
        elif (opt == '-h') or (opt == '--help'):
            sys.exit("""options :
                -u login personnel
                -m mot de passe
                -p prenom
                -f nom de famille
                [-d date de naissance (jj/mm/aaaa)]
                [-x civilité (1=M., 2=Mme, 3=Mlle)]
                [-M adresse mail ou mot clé "internet/restreint/aucun"]
                [-G service1,service2 ]
                [-q quota]
                [-P profil (1=local, 2=obligatoire-1, 3=obligatoire-2, 4=itinérant)]
                [-s activation du shell]
                -h (aide)
                """)

    if is_empty(prof, 'date'):
        # date de naissance bidon si nécessaire
        prof['date'] = '01/01/0000'
    if is_empty(prof, 'civilite'):
        # mec si nécessaire
        prof['civilite'] = '1'

    ldapprof = Administratif()
    try:
        ldapprof.add_one(**prof)
    except MissingUserCreateKey, msg:
        print "Erreur : Il manque un argument obligatoire (%s)" % msg
        sys.exit(1)
    except LdapExistingUser:
        print "Erreur : Le login %(login)s n'est pas disponible" % prof
        sys.exit(1)
    except Exception, msg:
        print "Erreur : %s" % str(msg)
        sys.exit(1)

    print "L'utilisateur %(login)s (%(prenom)s %(nom)s) a été ajouté" % prof
    sys.exit(0)

if __name__ == "__main__":
    main()
